using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using Syncfusion.Windows.Forms.Grid;

namespace TypeToRowGrid
{
	/// <summary>
	/// Summary description for TypeToHelper.
	/// </summary>
	public class TypeToHelper
	{
		public TypeToHelper()
		{

		}

		private GridControlBase grid;
		private string searchString = "";
		private bool inSearch = false;
		
		public void WireGrid(GridControlBase grid)
		{
			this.grid = grid;
			this.grid.Model.Options.ActivateCurrentCellBehavior = GridCellActivateAction.None;
			this.grid.CurrentCellStartEditing += new CancelEventHandler(grid_CurrentCellStartEditing);
			this.grid.CurrentCellMoved += new GridCurrentCellMovedEventHandler(grid_CurrentCellMoved);
			this.grid.KeyDown += new KeyEventHandler(grid_KeyDown);
		}

		private void grid_CurrentCellMoved(object sender, GridCurrentCellMovedEventArgs e)
		{
			if(!inSearch)
				searchString = "";
		}

		private void grid_CurrentCellStartEditing(object sender, CancelEventArgs e)
		{
			e.Cancel = true;
		}

		private void grid_KeyDown(object sender, KeyEventArgs e)
		{
			 
			if(char.IsLetterOrDigit((char)e.KeyValue))
			{
				this.searchString += (char)e.KeyValue;
				this.searchString = this.searchString.ToUpper();
				PositionCurrentCellToString();
			}
		}

		private void PositionCurrentCellToString()
		{
			if(this.searchString.Length > 0)
			{
				int row = this.grid.CurrentCell.RowIndex;
				int col = this.grid.CurrentCell.ColIndex;
				while( row <= this.grid.Model.RowCount 
					   && !this.grid.Model[row, col].Text.ToUpper().StartsWith(this.searchString))
					row ++;
				if(row > this.grid.Model.RowCount 
					|| !this.grid.Model[row, col].Text.ToUpper().StartsWith(this.searchString))
				{
					row = 1;
					while( row <= this.grid.CurrentCell.RowIndex
						&& !this.grid.Model[row, col].Text.ToUpper().StartsWith(this.searchString))
						row ++;
				}
				if( row <= this.grid.Model.RowCount
						&& this.grid.Model[row, col].Text.ToUpper().StartsWith(this.searchString))
				{
					inSearch = true;
					this.grid.CurrentCell.MoveTo(row, col, GridSetCurrentCellOptions.ScrollInView);
					inSearch = false;
				}
			}
		}
	}
}
